from setuptools import setup, find_packages
setup(
      name="SchedComp",
      version="1.1.1",
      py_modules=["main_zeromq"],
      packages=find_packages(where="."),
      install_requires=['ZeroMqMessageHandler==2.0.0', 'EdpHelper==0.16', 'TimeUtil==0.2', 'crontab==0.22.9'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)
